#!/bin/bash

# psxc-symlink-maker
# an example addon for psxc-imdb
# this addon first appeared in psxc-imdb v2.0j
#
# in order for this to work, you should copy this file to
# /glftpd/bin and change the variable EXTERNALSCRIPTNAME
# in psxc-imdb.conf to "$GLROOT/bin/psxc-symlink-maker.sh"
###########################################################

# Config.
# After you're done configging, run the script from shell. It will test a
# few variables/settings and report back to you.
# You can also put the config here in psxc-imdb.conf - the variables there
# will override the ones here. Good to know for future updates. :)
############################################################################

# version number. no need to change
VERSION=2.0k

# The location of psxc-imdb.conf. This is the full path.
IMDB_CONF=/glftpd/etc/psxc-imdb.conf

# Where should symlinks be put? This is relative to $GLROOT.
SYMLINK_PATH=/site/MOVIES_SORTED

# What should we sort after? 0 disables, 1 enables.
# Genre is *all* genres listed. Year is, well, the year. Score is based on
# the score without decimal (0 to 10). Title is based on the first letter/number
# in the title.
SORT_BY_GENRE=1
SORT_BY_YEAR=1
SORT_BY_SCORE=1
SORT_BY_TITLE=1
SORT_BY_GROUP=1

# Here we specify the name of the dirs for the sorted releases.
SORT_BY_GENRE_NAME="Sorted.by.Genre"
SORT_BY_YEAR_NAME="Sorted.by.Year"
SORT_BY_SCORE_NAME="Sorted.by.Score"
SORT_BY_TITLE_NAME="Sorted.by.Title"
SORT_BY_GROUP_NAME="Sorted.by.Group"

# Clean up dead symlinks after each run? Usually, this is done pretty quick,
# but can take time, so use the trial and error method on this ;)
# Please note that only the used SORT_BY cathegories is being scanned for
# dead symlinks.
CLEANUP_SYMLINKS=1

# End of config
############################################################

# First, let's grab the variables found in psxc-imdb.conf.
# Yes, the dot (.) in front is correct - do not remove it.
# If you put the above variables in psxc-imdb.conf, they will override what is
# put in this file. Should be helpful if you want all variables to be in one
# place.
. $IMDB_CONF

# The following is the routine to grab variables from psxc-imdb. It's a copy
# of the code in psxc-imdb-parser.sh in the /extras dir.

IFSORIG=$IFS
IFS="^"

# Initialize variables. bash is a bit limited, so we gotta do a "hack"
c=1
for a in `echo $@ | sed "s|\" \"|^|g"`; do
b[c]=$a
let c=c+1
done

IFS=$IFSORIG

# Give the variables some sensible names
IMDBDATE=${b[1]}
IMDBDOTFILE=${b[2]}
IMDBRELPATH=${b[3]}
IMDBDIRNAME=${b[4]}
IMDBURL=${b[5]}
IMDBTITLE=${b[6]}
IMDBGENRE=${b[7]}
IMDBRATING=${b[8]}
IMDBCOUNTRY=${b[9]}
IMDBLANGUAGE=${b[10]}
IMDBCERTIFICATION=${b[11]}
IMDBRUNTIME=${b[12]}
IMDBDIRECTOR=${b[13]}
IMDBBUSINESSDATA=${b[14]}
IMDBPREMIERE=${b[15]}
IMDBLIMITED=${b[16]}
IMDBVOTES=${b[17]}
IMDBSCORE=${b[18]}
IMDBNAME=${b[19]}
IMDBYEAR=${b[20]}
IMDBNUMSCREENS=${b[21]}
IMDBISLIMITED=${b[22]}
IMDBCASTLEADNAME=${b[23]}
IMDBCASTLEADCHAR=${b[24]}
IMDBTAGLINE=${b[25]}
IMDBPLOT=${b[26]}

###### Let's start

# First, a couple of test to make sure we got the variables. These should be better.
if [ -z "$GLROOT" ]; then
 echo "config error. check variables."
 exit 0
fi
if [ ! -z "`echo $SYMLINK_PATH | grep -v "/"`" ]; then
 echo "config error. check variables."
 exit 0
fi

# Let's check the if SYMLINK_PATH exist.
if [ ! -d $GLROOT$SYMLINK_PATH ]; then
 mkdir $GLROOT$SYMLINK_PATH >/dev/null 2>&1
 if [ $? -ne 0 ]; then
  echo "Could not create $GLROOT$SYMLINK_PATH. Exiting."
  exit 0
 fi
 chmod 777 $GLROOT$SYMLINK_PATH >/dev/null 2>&1
 if [ $? -ne 0 ]; then
  echo "Could not chmod 777 $GLROOT$SYMLINK_PATH. Exiting."
  exit 0
 fi
fi

# Make sure we are able to write in SYMLINK_PATH
if [ ! -w $GLROOT$SYMLINK_PATH ]; then
 echo "Unable to write to $GLROOT$SYMLINK_PATH. Exiting."
 exit 0
fi

if [ -z "$IMDBRELPATH" ]; then
 echo "Seems to me like you've run this script in standalone mode."
 echo "That's fine if you wish to clean up old symlinks. If this was"
 echo "not your intention, I suggest you read the docs on how to"
 echo "set this up."
fi

# finally, let's see if the release still exists. Maybe it's already been
# moved by a different script?
if [ ! -e $GLROOT/$IMDBRELPATH ]; then
 exit 0
fi

##### From here on I will assume the needed bins exists, and the correct permissions
##### are set. The above should've catched most of such errors.

# First, let's make sure we're not in an affil/pre/group/private dir
ISEXEMPT=0
if [ ! -z "$BOTEXEMPT" ]; then
 for EXEMPT in $BOTEXEMPT; do
  if [ ! -z "`echo "$IMDBRELPATH" | grep -e "$EXEMPT"`" ]; then
   ISEXEMPT=1
   break
  fi
 done
fi

# Genre Section.

if [ $SORT_BY_GENRE -eq 1 ]; then
 if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME ]; then
  mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME
  chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME
 fi

# Cleanup Genre-dirs
 if [ $CLEANUP_SYMLINKS -eq 1 ]; then
  GENRES="`ls -F $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/ | grep "/"`"
  if [ ! -z "$GENRES" ]; then
   for GENRE in $GENRES; do
    for GENRE_SYM in `ls -l $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE | grep ">" | cut -d '>' -f 2`; do
     if [ ! -e $GLROOT$GENRE_SYM ]; then
      rm -f  $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE`basename $GENRE_SYM`
     fi
    done
    rmdir $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE >/dev/null 2>&1
   done
  fi
 fi

# Make link if needed
 if [ ! -z "$IMDBGENRE" ] && [ ! $ISEXEMPT -eq 1 ]; then
  IMDBGENRES="`echo $IMDBGENRE | tr -s '/ ' ' '`"
  for GENRE in $IMDBGENRES; do
   if [ ! -d  $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE ]; then
    mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE
    chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE
   fi
   if [ ! -L $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE/$IMDBDIRNAME ]; then
    ln -s $IMDBRELPATH $GLROOT$SYMLINK_PATH/$SORT_BY_GENRE_NAME/$GENRE/$IMDBDIRNAME
   fi
  done
 fi
fi

# Year Section.

if [ $SORT_BY_YEAR -eq 1 ]; then
 if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME ]; then
  mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME
  chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME
 fi

# Cleanup Year-dirs
 if [ $CLEANUP_SYMLINKS -eq 1 ]; then
  YEARS="`ls -F $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/ | grep "/"`"
  if [ ! -z "$YEARS" ]; then
   for YEAR in $YEARS; do
    for YEAR_SYM in `ls -lF $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$YEAR | grep ">" | cut -d '>' -f 2`; do
     if [ ! -e $GLROOT$YEAR_SYM ]; then
      rm -f $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$YEAR`basename $YEAR_SYM`
     fi
    done
    rmdir $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$YEAR >/dev/null 2>&1
   done
  fi
 fi

# Make link if needed
 if [ ! -z "$IMDBYEAR" ] && [ ! $ISEXEMPT -eq 1 ]; then
  MYYEAR="`echo $IMDBYEAR | tr -cd '0-9'`"
  if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$MYYEAR ]; then
   mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$MYYEAR
   chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$MYYEAR
  fi
  if [ ! -L $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$MYYEAR/$IMDBDIRNAME ]; then
   ln -s $IMDBRELPATH $GLROOT$SYMLINK_PATH/$SORT_BY_YEAR_NAME/$MYYEAR/$IMDBDIRNAME
  fi
 fi
fi

# Score Section.

if [ $SORT_BY_SCORE -eq 1 ]; then
 if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME ]; then
  mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME
  chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME
 fi

# Cleanup Score-dirs
 if [ $CLEANUP_SYMLINKS -eq 1 ]; then
  SCORES="`ls -F $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/ | grep "/"`"
  if [ ! -z "$SCORES" ]; then
   for SCORE in $SCORES; do
    for SCORE_SYM in `ls -lF $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE | grep ">" | cut -d '>' -f 2`; do
     if [ ! -e $GLROOT$SCORE_SYM ]; then
      rm -f  $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE`basename $SCORE_SYM`
     fi
    done
    rmdir $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE >/dev/null 2>&1
   done
  fi
 fi

# Make link if needed
 if [ ! -z "$IMDBSCORE" ] && [ ! $ISEXEMPT -eq 1 ]; then
  SCORE="`echo $IMDBSCORE | cut -d '.' -f 1`"
  if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE ]; then
   mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE
   chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE
  fi
  if [ ! -L $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE/$IMDBDIRNAME ]; then
   ln -s $IMDBRELPATH $GLROOT$SYMLINK_PATH/$SORT_BY_SCORE_NAME/$SCORE/$IMDBDIRNAME
  fi
 fi
fi

# Title Section.

if [ $SORT_BY_TITLE -eq 1 ]; then
 if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME ]; then
  mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME
  chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME
 fi

# Cleanup Title-dirs
 if [ $CLEANUP_SYMLINKS -eq 1 ]; then
  TITLES="`ls -F $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/ | grep "/"`"
  if [ ! -z "$TITLES" ]; then
   for TITLE in $TITLES; do
    for TITLE_SYM in `ls -lF $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLE | grep -e ">" | tr -s ' ' '%' | sed "s|->|>|g"`; do
     TITLE_SYM_SRC=`echo "$TITLE_SYM" | cut -d '>' -f 1 | tr '%@' '\n' | grep -v "^$" | tail -n 1`
     TITLE_SYM_DST=`echo "$TITLE_SYM" | cut -d '>' -f 2 | tr -d '%'`
     if [ ! -e $GLROOT$TITLE_SYM_DST ]; then
      rm -f  $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLE`basename $TITLE_SYM_SRC`
     fi
    done
    rmdir $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLE >/dev/null 2>&1
   done
  fi
 fi

# Make link if needed
 if [ ! -z "$IMDBNAME" ] && [ ! $ISEXEMPT -eq 1 ]; then
  SECTION=`echo $IMDBRELPATH | tr '/' ' ' | wc -w`
  SECTIONNAME="`echo $IMDBRELPATH | cut -d '/' -f $SECTION`"
  TITLE="`echo $IMDBNAME | tr -sc 'A-Za-z0-9_\-()' '.'`""-.$SECTIONNAME"
  TITLECHAR=${TITLE:0:1}
  if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLECHAR ]; then
   mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLECHAR
   chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLECHAR
  fi
  if [ ! -L $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLECHAR/$TITLE ]; then
   ln -s $IMDBRELPATH $GLROOT$SYMLINK_PATH/$SORT_BY_TITLE_NAME/$TITLECHAR/$TITLE
  fi
 fi
fi

# Group Section.

if [ $SORT_BY_GROUP -eq 1 ]; then
 if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME ]; then
  mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME
  chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME
 fi

# Cleanup Group-dirs
 if [ $CLEANUP_SYMLINKS -eq 1 ]; then
  DIRGROUPS="`ls -F $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/ | grep "/"`"
  if [ ! -z "$DIRGROUPS" ]; then
   for GROUP in $DIRGROUPS; do
    for GROUP_SYM in `ls -lF $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP | grep ">" | cut -d '>' -f 2`; do
     if [ ! -e $GLROOT$GROUP_SYM ]; then
      rm -f  $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP`basename $GROUP_SYM`
     fi
    done
    rmdir $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP >/dev/null 2>&1
   done
  fi
 fi

# Make link if needed
 if [ ! -z "$IMDBRELPATH" ]; then
  GROUP="`basename $IMDBRELPATH | tr '-' '\n' | grep -v "^$" | tail -n 1`"
  if [ ! -z "$GROUP" ] && [ ! $ISEXEMPT -eq 1 ]; then
   if [ ! -d $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP ]; then
    mkdir $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP
    chmod 777 $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP
   fi
   if [ ! -L $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP/$IMDBDIRNAME ]; then
    ln -s $IMDBRELPATH $GLROOT$SYMLINK_PATH/$SORT_BY_GROUP_NAME/$GROUP/$IMDBDIRNAME
   fi
  fi
 fi
fi

# You should always exit with a 0 - the parent won't give a crap anyway,
# but just to make sure...
exit 0
