#!/bin/bash

# PSXC IMDB SANITY CHECK #
##########################

# This little thingy will check permissions, content etc in your setup. Hopefully, it will fix whatever
# problems you have. At least it's worth a try. It will not do anything dramatic (I hope), but imdb-logs
# may be cleaned etc. glftpd.log (or the equivalent in your setup) will be created if it do not exists,
# and chmod'ed world read-writable.

# version number. do not change.
VERSION="v0.1j"

# needed binaries. do not change.
BINARIES="date cat echo cut lynx grep head sed awk fold rm bash ls basename dirname chmod ps wc"
BINARIESCHROOT="grep tr sed head echo bash chmod basename pwd"

# your glftpd root path.
GLROOT=/glftpd

# path to the config file when chrooted by glftpd.
CONFFILE=/etc/psxc-imdb.conf

## End of config ##
###################

######################################################################################################

# check if configfile exists
############################

if [ -r $GLROOT$CONFFILE ]; then
 . $GLROOT$CONFFILE
 if [ $? -ne 0 ]; then
  echo "Unable to open config file ($GLROOT$CONFFILE). Forced to exit."
  exit 0
 fi
elif [ -r $CONFFILE ]; then
 . $CONFFILE
 if [ $? -ne 0 ]; then
  echo "Unable to open config file ($CONFFILE). Forced to exit."
  exit 0
 fi
else
 echo "Config file not found. Forced to exit."
 exit 0
fi

  echo "This script will do a few things to make sure the script can be run"
  echo "without too much fuss. First it will check to see if all binaries are"
  echo "present. If binaries are missing in $GLROOT/bin, it will try to copy"
  echo "the needed ones there. All binaries listed will be chmod'ed ugoa+rx."
  echo "Should a binary fail to be found, this program will exit, and you must"
  echo "either broaden the path or copy the file yourself. If the script cannot"
  echo "chmod the binaries, it will NOT exit, but it will report it, leaving"
  echo "you to make sure it has the correct permissions."
  echo ""
  echo "It will then check all needed logfiles, creating those not present and"
  echo "chmod them ugoa-rw. Should this fail, this program will abort, leaving"
  echo "you to fix it."
  echo "Lastly, it will check to see if your config-file is world readable."
  echo ""
  echo "It will not currently check permissions on psxc-imdb.sh or the tcl-files"
  echo "if you use them, so you're on your own there. And this is no substitute"
  echo "for a brain... Things could still go wrong."
  echo ""
  echo "This script will not do Something Bad to your files, and should be quite"
  echo "safe to run whenever you wish/need to. Please remember this if a future"
  echo "upgrade leaves you hanging high and dry - running this script might be"
  echo "able to fix your problem. If new files are introduced, this script will be"
  echo "updated, so make sure you use the most recent one availible."
  echo ""
  echo "PRESS <RETURN> TO CONTINUE, OR <CTRL-C> TO BREAK"; read line;
  echo ""
  echo "Searching in $GLROOT/bin: "
  for BINAR in $BINARIESCHROOT; do
   echo -n " $BINAR "
   test -e $GLROOT/bin/$BINAR || {
    echo ""
    echo "$BINAR missing. I'll try to fix...";
     if [ ! -z "`which $BINAR`" ]; then
      cp `which $BINAR` $GLROOT/bin/ || {
       echo "Unable to copy `which $BINAR` to $GLROOT/bin. Please try manually and run this script again."
       exit 1
      }
      echo "$BINAR copied. Continuing."
     else
      echo "Unable to find $BINAR in your path. Please try manually and run this script again."
      exit 1;
     fi
   };
   echo -n "found."
   chmod ugoa+rx $GLROOT/bin/$BINAR || {
    BINARPERM=`ls -l $GLROOT/bin/$BINAR | grep "$BINAR" | cut -d ' ' -f 1 | head -1`
    echo -n " Failed to chmod the file. Current permissions on file: $BINARPERM"
   }
   echo ""
  done
  echo ""
  echo "Searching in $PATH: "
  for BINAR in $BINARIES; do
   echo -n " $BINAR "
   which $BINAR >/dev/null 2>&1 || {
    echo ""
    echo "$BINAR missing/not in path. Please fix."
    exit 1
   }
   echo -n "found."
   chmod ugoa+rx `which $BINAR` || {
    BINARWHICH=`which $BINAR`
    BINARPERM=`ls -l $BINARWHICH | grep "$BINAR" | cut -d ' ' -f 1 | head -1`
    echo -n " Failed to chmod the file. Current permissions on file: $BINARPERM"
   }
   echo ""
  done
  echo ""
  echo "Initializing the files..."
  echo -n " $GLLOG .. "
  if [ ! -e $GLLOG ]; then
   touch $GLLOG >/dev/null 2>&1 || { echo "ERROR! Could not create \$GLLOG ($GLLOG)"; exit 1; };
  fi
  chmod ugoa+rw $GLLOG || { echo "could not make $GLLOG world writable."; exit 1; };
  echo "OK."
  echo -n " $TMPFILE .. "
  touch $TMPFILE >/dev/null 2>&1 || { echo "ERROR! Could not create \$TMPFILE ($TMPFILE)"; exit 1; };
  chmod ugoa+rw $TMPFILE || { echo "could not make $TMPFILE world writable."; exit 1; };
  echo "OK."
  echo -n " $IMDBURLLOG .. "
  touch $IMDBURLLOG >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBURLLOG ($IMDBURLLOG)"; exit 1; };
  chmod ugoa+rw $IMDBURLLOG || { echo "could not make $IMDBURLLOG world writable."; exit 1; };
  echo "OK."
  echo -n " $IMDBLOG .. "
  touch $IMDBLOG >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBLOG ($IMDBLOG)"; exit 1; };
  chmod ugoa+rw $IMDBLOG || { echo "could not make $IMDBLOG world writable."; exit 1; };
  echo "OK."
  echo -n " $IMDBPID .. "
  touch $IMDBPID >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBPID ($IMDBPID)"; exit 1; };
  chmod ugoa+rw $IMDBPID || { echo "could not make $IMDBPID world writable."; exit 1; };
  echo "OK."
  echo -n " $GLROOT$CONFFILE .. "
  chmod ugoa+r $GLROOT$CONFFILE || { echo "could not make $GLROOT$CONFFILE world readable."; exit 1; };
  echo "OK."
  echo -n " $GLROOT/bin/$PRENAME .. "
  if [ ! -e $GLROOT/bin/$PRENAME ]; then
   if [ -e $GLROOT/bin/psxc-imdb.sh ]; then
    cd $GLROOT/bin
    ln -s psxc-imdb.sh $PRENAME || { echo "could not make symlink to psxc-imdb. Please make it yourself."; break; };
    echo "OK."
   else
    echo "could not find psxc-imdb.sh in $GLROOT/bin. You must make the symlink yourself."
   fi
  else
   echo "symlink already exist."
  fi
  echo ""
  if [ ! -e /bin/bash ]; then
   echo -n "/bin/bash not found. Will try to link it there.."
   ln -s `which bash` /bin/ || { echo "could not make symlink to /bin/bash. Please make it yourself."; break; };
   echo "Done."
   echo ""
  fi
  echo "Done testing. Everything seems to be okay."
  exit 0
 fi

